/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataprocGdcServiceInstanceConfig extends cdktf.TerraformMetaArguments {
    /**
    * User-provided human-readable name to be used in user interfaces.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/dataproc_gdc_service_instance#display_name DataprocGdcServiceInstance#display_name}
    */
    readonly displayName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/dataproc_gdc_service_instance#id DataprocGdcServiceInstance#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The labels to associate with this service instance. Labels may be used for filtering and billing tracking.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/dataproc_gdc_service_instance#labels DataprocGdcServiceInstance#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Location of the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/dataproc_gdc_service_instance#location DataprocGdcServiceInstance#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/dataproc_gdc_service_instance#project DataprocGdcServiceInstance#project}
    */
    readonly project?: string;
    /**
    * Requested service account to associate with ServiceInstance.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/dataproc_gdc_service_instance#service_account DataprocGdcServiceInstance#service_account}
    */
    readonly serviceAccount?: string;
    /**
    * Id of the service instance.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/dataproc_gdc_service_instance#service_instance_id DataprocGdcServiceInstance#service_instance_id}
    */
    readonly serviceInstanceId: string;
    /**
    * gdce_cluster block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/dataproc_gdc_service_instance#gdce_cluster DataprocGdcServiceInstance#gdce_cluster}
    */
    readonly gdceCluster?: DataprocGdcServiceInstanceGdceCluster;
    /**
    * spark_service_instance_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/dataproc_gdc_service_instance#spark_service_instance_config DataprocGdcServiceInstance#spark_service_instance_config}
    */
    readonly sparkServiceInstanceConfig?: DataprocGdcServiceInstanceSparkServiceInstanceConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/dataproc_gdc_service_instance#timeouts DataprocGdcServiceInstance#timeouts}
    */
    readonly timeouts?: DataprocGdcServiceInstanceTimeouts;
}
export interface DataprocGdcServiceInstanceGdceCluster {
    /**
    * Gdce cluster resource id.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/dataproc_gdc_service_instance#gdce_cluster DataprocGdcServiceInstance#gdce_cluster}
    */
    readonly gdceCluster: string;
}
export declare function dataprocGdcServiceInstanceGdceClusterToTerraform(struct?: DataprocGdcServiceInstanceGdceClusterOutputReference | DataprocGdcServiceInstanceGdceCluster): any;
export declare function dataprocGdcServiceInstanceGdceClusterToHclTerraform(struct?: DataprocGdcServiceInstanceGdceClusterOutputReference | DataprocGdcServiceInstanceGdceCluster): any;
export declare class DataprocGdcServiceInstanceGdceClusterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataprocGdcServiceInstanceGdceCluster | undefined;
    set internalValue(value: DataprocGdcServiceInstanceGdceCluster | undefined);
    private _gdceCluster?;
    get gdceCluster(): string;
    set gdceCluster(value: string);
    get gdceClusterInput(): string | undefined;
}
export interface DataprocGdcServiceInstanceSparkServiceInstanceConfig {
}
export declare function dataprocGdcServiceInstanceSparkServiceInstanceConfigToTerraform(struct?: DataprocGdcServiceInstanceSparkServiceInstanceConfigOutputReference | DataprocGdcServiceInstanceSparkServiceInstanceConfig): any;
export declare function dataprocGdcServiceInstanceSparkServiceInstanceConfigToHclTerraform(struct?: DataprocGdcServiceInstanceSparkServiceInstanceConfigOutputReference | DataprocGdcServiceInstanceSparkServiceInstanceConfig): any;
export declare class DataprocGdcServiceInstanceSparkServiceInstanceConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataprocGdcServiceInstanceSparkServiceInstanceConfig | undefined;
    set internalValue(value: DataprocGdcServiceInstanceSparkServiceInstanceConfig | undefined);
}
export interface DataprocGdcServiceInstanceTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/dataproc_gdc_service_instance#create DataprocGdcServiceInstance#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/dataproc_gdc_service_instance#delete DataprocGdcServiceInstance#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/dataproc_gdc_service_instance#update DataprocGdcServiceInstance#update}
    */
    readonly update?: string;
}
export declare function dataprocGdcServiceInstanceTimeoutsToTerraform(struct?: DataprocGdcServiceInstanceTimeouts | cdktf.IResolvable): any;
export declare function dataprocGdcServiceInstanceTimeoutsToHclTerraform(struct?: DataprocGdcServiceInstanceTimeouts | cdktf.IResolvable): any;
export declare class DataprocGdcServiceInstanceTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataprocGdcServiceInstanceTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: DataprocGdcServiceInstanceTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/dataproc_gdc_service_instance google_dataproc_gdc_service_instance}
*/
export declare class DataprocGdcServiceInstance extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_dataproc_gdc_service_instance";
    /**
    * Generates CDKTF code for importing a DataprocGdcServiceInstance resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataprocGdcServiceInstance to import
    * @param importFromId The id of the existing DataprocGdcServiceInstance that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/dataproc_gdc_service_instance#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataprocGdcServiceInstance to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/dataproc_gdc_service_instance google_dataproc_gdc_service_instance} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataprocGdcServiceInstanceConfig
    */
    constructor(scope: Construct, id: string, config: DataprocGdcServiceInstanceConfig);
    get createTime(): string;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    get effectiveServiceAccount(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get reconciling(): cdktf.IResolvable;
    get requestedState(): string;
    private _serviceAccount?;
    get serviceAccount(): string;
    set serviceAccount(value: string);
    resetServiceAccount(): void;
    get serviceAccountInput(): string | undefined;
    private _serviceInstanceId?;
    get serviceInstanceId(): string;
    set serviceInstanceId(value: string);
    get serviceInstanceIdInput(): string | undefined;
    get state(): string;
    get stateMessage(): string;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get uid(): string;
    get updateTime(): string;
    private _gdceCluster;
    get gdceCluster(): DataprocGdcServiceInstanceGdceClusterOutputReference;
    putGdceCluster(value: DataprocGdcServiceInstanceGdceCluster): void;
    resetGdceCluster(): void;
    get gdceClusterInput(): DataprocGdcServiceInstanceGdceCluster | undefined;
    private _sparkServiceInstanceConfig;
    get sparkServiceInstanceConfig(): DataprocGdcServiceInstanceSparkServiceInstanceConfigOutputReference;
    putSparkServiceInstanceConfig(value: DataprocGdcServiceInstanceSparkServiceInstanceConfig): void;
    resetSparkServiceInstanceConfig(): void;
    get sparkServiceInstanceConfigInput(): DataprocGdcServiceInstanceSparkServiceInstanceConfig | undefined;
    private _timeouts;
    get timeouts(): DataprocGdcServiceInstanceTimeoutsOutputReference;
    putTimeouts(value: DataprocGdcServiceInstanceTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | DataprocGdcServiceInstanceTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
