/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface HealthcarePipelineJobConfig extends cdktf.TerraformMetaArguments {
    /**
    * Healthcare Dataset under which the Pipeline Job is to run
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#dataset HealthcarePipelineJob#dataset}
    */
    readonly dataset: string;
    /**
    * If true, disables writing lineage for the pipeline.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#disable_lineage HealthcarePipelineJob#disable_lineage}
    */
    readonly disableLineage?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#id HealthcarePipelineJob#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * User-supplied key-value pairs used to organize Pipeline Jobs.
    * Label keys must be between 1 and 63 characters long, have a UTF-8 encoding of
    * maximum 128 bytes, and must conform to the following PCRE regular expression:
    * [\p{Ll}\p{Lo}][\p{Ll}\p{Lo}\p{N}_-]{0,62}
    * Label values are optional, must be between 1 and 63 characters long, have a
    * UTF-8 encoding of maximum 128 bytes, and must conform to the following PCRE
    * regular expression: [\p{Ll}\p{Lo}\p{N}_-]{0,63}
    * No more than 64 labels can be associated with a given pipeline.
    * An object containing a list of "key": value pairs.
    * Example: { "name": "wrench", "mass": "1.3kg", "count": "3" }.
    *
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#labels HealthcarePipelineJob#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Location where the Pipeline Job is to run
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#location HealthcarePipelineJob#location}
    */
    readonly location: string;
    /**
    * Specifies the name of the pipeline job. This field is user-assigned.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#name HealthcarePipelineJob#name}
    */
    readonly name: string;
    /**
    * backfill_pipeline_job block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#backfill_pipeline_job HealthcarePipelineJob#backfill_pipeline_job}
    */
    readonly backfillPipelineJob?: HealthcarePipelineJobBackfillPipelineJob;
    /**
    * mapping_pipeline_job block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#mapping_pipeline_job HealthcarePipelineJob#mapping_pipeline_job}
    */
    readonly mappingPipelineJob?: HealthcarePipelineJobMappingPipelineJob;
    /**
    * reconciliation_pipeline_job block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#reconciliation_pipeline_job HealthcarePipelineJob#reconciliation_pipeline_job}
    */
    readonly reconciliationPipelineJob?: HealthcarePipelineJobReconciliationPipelineJob;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#timeouts HealthcarePipelineJob#timeouts}
    */
    readonly timeouts?: HealthcarePipelineJobTimeouts;
}
export interface HealthcarePipelineJobBackfillPipelineJob {
    /**
    * Specifies the mapping pipeline job to backfill, the name format
    * should follow: projects/{projectId}/locations/{locationId}/datasets/{datasetId}/pipelineJobs/{pipelineJobId}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#mapping_pipeline_job HealthcarePipelineJob#mapping_pipeline_job}
    */
    readonly mappingPipelineJob?: string;
}
export declare function healthcarePipelineJobBackfillPipelineJobToTerraform(struct?: HealthcarePipelineJobBackfillPipelineJobOutputReference | HealthcarePipelineJobBackfillPipelineJob): any;
export declare function healthcarePipelineJobBackfillPipelineJobToHclTerraform(struct?: HealthcarePipelineJobBackfillPipelineJobOutputReference | HealthcarePipelineJobBackfillPipelineJob): any;
export declare class HealthcarePipelineJobBackfillPipelineJobOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): HealthcarePipelineJobBackfillPipelineJob | undefined;
    set internalValue(value: HealthcarePipelineJobBackfillPipelineJob | undefined);
    private _mappingPipelineJob?;
    get mappingPipelineJob(): string;
    set mappingPipelineJob(value: string);
    resetMappingPipelineJob(): void;
    get mappingPipelineJobInput(): string | undefined;
}
export interface HealthcarePipelineJobMappingPipelineJobFhirStreamingSource {
    /**
    * Describes the streaming FHIR data source.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#description HealthcarePipelineJob#description}
    */
    readonly description?: string;
    /**
    * The path to the FHIR store in the format projects/{projectId}/locations/{locationId}/datasets/{datasetId}/fhirStores/{fhirStoreId}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#fhir_store HealthcarePipelineJob#fhir_store}
    */
    readonly fhirStore: string;
}
export declare function healthcarePipelineJobMappingPipelineJobFhirStreamingSourceToTerraform(struct?: HealthcarePipelineJobMappingPipelineJobFhirStreamingSourceOutputReference | HealthcarePipelineJobMappingPipelineJobFhirStreamingSource): any;
export declare function healthcarePipelineJobMappingPipelineJobFhirStreamingSourceToHclTerraform(struct?: HealthcarePipelineJobMappingPipelineJobFhirStreamingSourceOutputReference | HealthcarePipelineJobMappingPipelineJobFhirStreamingSource): any;
export declare class HealthcarePipelineJobMappingPipelineJobFhirStreamingSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): HealthcarePipelineJobMappingPipelineJobFhirStreamingSource | undefined;
    set internalValue(value: HealthcarePipelineJobMappingPipelineJobFhirStreamingSource | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _fhirStore?;
    get fhirStore(): string;
    set fhirStore(value: string);
    get fhirStoreInput(): string | undefined;
}
export interface HealthcarePipelineJobMappingPipelineJobMappingConfigWhistleConfigSource {
    /**
    * Directory path where all the Whistle files are located.
    * Example: gs://{bucket-id}/{path/to/import-root/dir}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#import_uri_prefix HealthcarePipelineJob#import_uri_prefix}
    */
    readonly importUriPrefix: string;
    /**
    * Main configuration file which has the entrypoint or the root function.
    * Example: gs://{bucket-id}/{path/to/import-root/dir}/entrypoint-file-name.wstl.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#uri HealthcarePipelineJob#uri}
    */
    readonly uri: string;
}
export declare function healthcarePipelineJobMappingPipelineJobMappingConfigWhistleConfigSourceToTerraform(struct?: HealthcarePipelineJobMappingPipelineJobMappingConfigWhistleConfigSourceOutputReference | HealthcarePipelineJobMappingPipelineJobMappingConfigWhistleConfigSource): any;
export declare function healthcarePipelineJobMappingPipelineJobMappingConfigWhistleConfigSourceToHclTerraform(struct?: HealthcarePipelineJobMappingPipelineJobMappingConfigWhistleConfigSourceOutputReference | HealthcarePipelineJobMappingPipelineJobMappingConfigWhistleConfigSource): any;
export declare class HealthcarePipelineJobMappingPipelineJobMappingConfigWhistleConfigSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): HealthcarePipelineJobMappingPipelineJobMappingConfigWhistleConfigSource | undefined;
    set internalValue(value: HealthcarePipelineJobMappingPipelineJobMappingConfigWhistleConfigSource | undefined);
    private _importUriPrefix?;
    get importUriPrefix(): string;
    set importUriPrefix(value: string);
    get importUriPrefixInput(): string | undefined;
    private _uri?;
    get uri(): string;
    set uri(value: string);
    get uriInput(): string | undefined;
}
export interface HealthcarePipelineJobMappingPipelineJobMappingConfig {
    /**
    * Describes the mapping configuration.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#description HealthcarePipelineJob#description}
    */
    readonly description?: string;
    /**
    * whistle_config_source block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#whistle_config_source HealthcarePipelineJob#whistle_config_source}
    */
    readonly whistleConfigSource?: HealthcarePipelineJobMappingPipelineJobMappingConfigWhistleConfigSource;
}
export declare function healthcarePipelineJobMappingPipelineJobMappingConfigToTerraform(struct?: HealthcarePipelineJobMappingPipelineJobMappingConfigOutputReference | HealthcarePipelineJobMappingPipelineJobMappingConfig): any;
export declare function healthcarePipelineJobMappingPipelineJobMappingConfigToHclTerraform(struct?: HealthcarePipelineJobMappingPipelineJobMappingConfigOutputReference | HealthcarePipelineJobMappingPipelineJobMappingConfig): any;
export declare class HealthcarePipelineJobMappingPipelineJobMappingConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): HealthcarePipelineJobMappingPipelineJobMappingConfig | undefined;
    set internalValue(value: HealthcarePipelineJobMappingPipelineJobMappingConfig | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _whistleConfigSource;
    get whistleConfigSource(): HealthcarePipelineJobMappingPipelineJobMappingConfigWhistleConfigSourceOutputReference;
    putWhistleConfigSource(value: HealthcarePipelineJobMappingPipelineJobMappingConfigWhistleConfigSource): void;
    resetWhistleConfigSource(): void;
    get whistleConfigSourceInput(): HealthcarePipelineJobMappingPipelineJobMappingConfigWhistleConfigSource | undefined;
}
export interface HealthcarePipelineJobMappingPipelineJob {
    /**
    * If set, the mapping pipeline will write snapshots to this
    * FHIR store without assigning stable IDs. You must
    * grant your pipeline project's Cloud Healthcare Service
    * Agent serviceaccount healthcare.fhirResources.executeBundle
    * and healthcare.fhirResources.create permissions on the
    * destination store. The destination store must set
    * [disableReferentialIntegrity][FhirStore.disable_referential_integrity]
    * to true. The destination store must use FHIR version R4.
    * Format: project/{projectID}/locations/{locationID}/datasets/{datasetName}/fhirStores/{fhirStoreID}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#fhir_store_destination HealthcarePipelineJob#fhir_store_destination}
    */
    readonly fhirStoreDestination?: string;
    /**
    * If set to true, a mapping pipeline will send output snapshots
    * to the reconciliation pipeline in its dataset. A reconciliation
    * pipeline must exist in this dataset before a mapping pipeline
    * with a reconciliation destination can be created.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#reconciliation_destination HealthcarePipelineJob#reconciliation_destination}
    */
    readonly reconciliationDestination?: boolean | cdktf.IResolvable;
    /**
    * fhir_streaming_source block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#fhir_streaming_source HealthcarePipelineJob#fhir_streaming_source}
    */
    readonly fhirStreamingSource?: HealthcarePipelineJobMappingPipelineJobFhirStreamingSource;
    /**
    * mapping_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#mapping_config HealthcarePipelineJob#mapping_config}
    */
    readonly mappingConfig: HealthcarePipelineJobMappingPipelineJobMappingConfig;
}
export declare function healthcarePipelineJobMappingPipelineJobToTerraform(struct?: HealthcarePipelineJobMappingPipelineJobOutputReference | HealthcarePipelineJobMappingPipelineJob): any;
export declare function healthcarePipelineJobMappingPipelineJobToHclTerraform(struct?: HealthcarePipelineJobMappingPipelineJobOutputReference | HealthcarePipelineJobMappingPipelineJob): any;
export declare class HealthcarePipelineJobMappingPipelineJobOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): HealthcarePipelineJobMappingPipelineJob | undefined;
    set internalValue(value: HealthcarePipelineJobMappingPipelineJob | undefined);
    private _fhirStoreDestination?;
    get fhirStoreDestination(): string;
    set fhirStoreDestination(value: string);
    resetFhirStoreDestination(): void;
    get fhirStoreDestinationInput(): string | undefined;
    private _reconciliationDestination?;
    get reconciliationDestination(): boolean | cdktf.IResolvable;
    set reconciliationDestination(value: boolean | cdktf.IResolvable);
    resetReconciliationDestination(): void;
    get reconciliationDestinationInput(): boolean | cdktf.IResolvable | undefined;
    private _fhirStreamingSource;
    get fhirStreamingSource(): HealthcarePipelineJobMappingPipelineJobFhirStreamingSourceOutputReference;
    putFhirStreamingSource(value: HealthcarePipelineJobMappingPipelineJobFhirStreamingSource): void;
    resetFhirStreamingSource(): void;
    get fhirStreamingSourceInput(): HealthcarePipelineJobMappingPipelineJobFhirStreamingSource | undefined;
    private _mappingConfig;
    get mappingConfig(): HealthcarePipelineJobMappingPipelineJobMappingConfigOutputReference;
    putMappingConfig(value: HealthcarePipelineJobMappingPipelineJobMappingConfig): void;
    get mappingConfigInput(): HealthcarePipelineJobMappingPipelineJobMappingConfig | undefined;
}
export interface HealthcarePipelineJobReconciliationPipelineJobMergeConfigWhistleConfigSource {
    /**
    * Directory path where all the Whistle files are located.
    * Example: gs://{bucket-id}/{path/to/import-root/dir}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#import_uri_prefix HealthcarePipelineJob#import_uri_prefix}
    */
    readonly importUriPrefix: string;
    /**
    * Main configuration file which has the entrypoint or the root function.
    * Example: gs://{bucket-id}/{path/to/import-root/dir}/entrypoint-file-name.wstl.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#uri HealthcarePipelineJob#uri}
    */
    readonly uri: string;
}
export declare function healthcarePipelineJobReconciliationPipelineJobMergeConfigWhistleConfigSourceToTerraform(struct?: HealthcarePipelineJobReconciliationPipelineJobMergeConfigWhistleConfigSourceOutputReference | HealthcarePipelineJobReconciliationPipelineJobMergeConfigWhistleConfigSource): any;
export declare function healthcarePipelineJobReconciliationPipelineJobMergeConfigWhistleConfigSourceToHclTerraform(struct?: HealthcarePipelineJobReconciliationPipelineJobMergeConfigWhistleConfigSourceOutputReference | HealthcarePipelineJobReconciliationPipelineJobMergeConfigWhistleConfigSource): any;
export declare class HealthcarePipelineJobReconciliationPipelineJobMergeConfigWhistleConfigSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): HealthcarePipelineJobReconciliationPipelineJobMergeConfigWhistleConfigSource | undefined;
    set internalValue(value: HealthcarePipelineJobReconciliationPipelineJobMergeConfigWhistleConfigSource | undefined);
    private _importUriPrefix?;
    get importUriPrefix(): string;
    set importUriPrefix(value: string);
    get importUriPrefixInput(): string | undefined;
    private _uri?;
    get uri(): string;
    set uri(value: string);
    get uriInput(): string | undefined;
}
export interface HealthcarePipelineJobReconciliationPipelineJobMergeConfig {
    /**
    * Describes the mapping configuration.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#description HealthcarePipelineJob#description}
    */
    readonly description?: string;
    /**
    * whistle_config_source block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#whistle_config_source HealthcarePipelineJob#whistle_config_source}
    */
    readonly whistleConfigSource: HealthcarePipelineJobReconciliationPipelineJobMergeConfigWhistleConfigSource;
}
export declare function healthcarePipelineJobReconciliationPipelineJobMergeConfigToTerraform(struct?: HealthcarePipelineJobReconciliationPipelineJobMergeConfigOutputReference | HealthcarePipelineJobReconciliationPipelineJobMergeConfig): any;
export declare function healthcarePipelineJobReconciliationPipelineJobMergeConfigToHclTerraform(struct?: HealthcarePipelineJobReconciliationPipelineJobMergeConfigOutputReference | HealthcarePipelineJobReconciliationPipelineJobMergeConfig): any;
export declare class HealthcarePipelineJobReconciliationPipelineJobMergeConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): HealthcarePipelineJobReconciliationPipelineJobMergeConfig | undefined;
    set internalValue(value: HealthcarePipelineJobReconciliationPipelineJobMergeConfig | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _whistleConfigSource;
    get whistleConfigSource(): HealthcarePipelineJobReconciliationPipelineJobMergeConfigWhistleConfigSourceOutputReference;
    putWhistleConfigSource(value: HealthcarePipelineJobReconciliationPipelineJobMergeConfigWhistleConfigSource): void;
    get whistleConfigSourceInput(): HealthcarePipelineJobReconciliationPipelineJobMergeConfigWhistleConfigSource | undefined;
}
export interface HealthcarePipelineJobReconciliationPipelineJob {
    /**
    * The harmonized FHIR store to write harmonized FHIR resources to,
    * in the format of: project/{projectID}/locations/{locationID}/datasets/{datasetName}/fhirStores/{id}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#fhir_store_destination HealthcarePipelineJob#fhir_store_destination}
    */
    readonly fhirStoreDestination?: string;
    /**
    * Specifies the top level directory of the matching configs used
    * in all mapping pipelines, which extract properties for resources
    * to be matched on.
    * Example: gs://{bucket-id}/{path/to/matching/configs}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#matching_uri_prefix HealthcarePipelineJob#matching_uri_prefix}
    */
    readonly matchingUriPrefix: string;
    /**
    * merge_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#merge_config HealthcarePipelineJob#merge_config}
    */
    readonly mergeConfig: HealthcarePipelineJobReconciliationPipelineJobMergeConfig;
}
export declare function healthcarePipelineJobReconciliationPipelineJobToTerraform(struct?: HealthcarePipelineJobReconciliationPipelineJobOutputReference | HealthcarePipelineJobReconciliationPipelineJob): any;
export declare function healthcarePipelineJobReconciliationPipelineJobToHclTerraform(struct?: HealthcarePipelineJobReconciliationPipelineJobOutputReference | HealthcarePipelineJobReconciliationPipelineJob): any;
export declare class HealthcarePipelineJobReconciliationPipelineJobOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): HealthcarePipelineJobReconciliationPipelineJob | undefined;
    set internalValue(value: HealthcarePipelineJobReconciliationPipelineJob | undefined);
    private _fhirStoreDestination?;
    get fhirStoreDestination(): string;
    set fhirStoreDestination(value: string);
    resetFhirStoreDestination(): void;
    get fhirStoreDestinationInput(): string | undefined;
    private _matchingUriPrefix?;
    get matchingUriPrefix(): string;
    set matchingUriPrefix(value: string);
    get matchingUriPrefixInput(): string | undefined;
    private _mergeConfig;
    get mergeConfig(): HealthcarePipelineJobReconciliationPipelineJobMergeConfigOutputReference;
    putMergeConfig(value: HealthcarePipelineJobReconciliationPipelineJobMergeConfig): void;
    get mergeConfigInput(): HealthcarePipelineJobReconciliationPipelineJobMergeConfig | undefined;
}
export interface HealthcarePipelineJobTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#create HealthcarePipelineJob#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#delete HealthcarePipelineJob#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#update HealthcarePipelineJob#update}
    */
    readonly update?: string;
}
export declare function healthcarePipelineJobTimeoutsToTerraform(struct?: HealthcarePipelineJobTimeouts | cdktf.IResolvable): any;
export declare function healthcarePipelineJobTimeoutsToHclTerraform(struct?: HealthcarePipelineJobTimeouts | cdktf.IResolvable): any;
export declare class HealthcarePipelineJobTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): HealthcarePipelineJobTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: HealthcarePipelineJobTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job google_healthcare_pipeline_job}
*/
export declare class HealthcarePipelineJob extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_healthcare_pipeline_job";
    /**
    * Generates CDKTF code for importing a HealthcarePipelineJob resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the HealthcarePipelineJob to import
    * @param importFromId The id of the existing HealthcarePipelineJob that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the HealthcarePipelineJob to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_pipeline_job google_healthcare_pipeline_job} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options HealthcarePipelineJobConfig
    */
    constructor(scope: Construct, id: string, config: HealthcarePipelineJobConfig);
    private _dataset?;
    get dataset(): string;
    set dataset(value: string);
    get datasetInput(): string | undefined;
    private _disableLineage?;
    get disableLineage(): boolean | cdktf.IResolvable;
    set disableLineage(value: boolean | cdktf.IResolvable);
    resetDisableLineage(): void;
    get disableLineageInput(): boolean | cdktf.IResolvable | undefined;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get selfLink(): string;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    private _backfillPipelineJob;
    get backfillPipelineJob(): HealthcarePipelineJobBackfillPipelineJobOutputReference;
    putBackfillPipelineJob(value: HealthcarePipelineJobBackfillPipelineJob): void;
    resetBackfillPipelineJob(): void;
    get backfillPipelineJobInput(): HealthcarePipelineJobBackfillPipelineJob | undefined;
    private _mappingPipelineJob;
    get mappingPipelineJob(): HealthcarePipelineJobMappingPipelineJobOutputReference;
    putMappingPipelineJob(value: HealthcarePipelineJobMappingPipelineJob): void;
    resetMappingPipelineJob(): void;
    get mappingPipelineJobInput(): HealthcarePipelineJobMappingPipelineJob | undefined;
    private _reconciliationPipelineJob;
    get reconciliationPipelineJob(): HealthcarePipelineJobReconciliationPipelineJobOutputReference;
    putReconciliationPipelineJob(value: HealthcarePipelineJobReconciliationPipelineJob): void;
    resetReconciliationPipelineJob(): void;
    get reconciliationPipelineJobInput(): HealthcarePipelineJobReconciliationPipelineJob | undefined;
    private _timeouts;
    get timeouts(): HealthcarePipelineJobTimeoutsOutputReference;
    putTimeouts(value: HealthcarePipelineJobTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | HealthcarePipelineJobTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
