/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface HealthcareWorkspaceConfig extends cdktf.TerraformMetaArguments {
    /**
    * Identifies the dataset addressed by this request. Must be in the format
    * 'projects/{project}/locations/{location}/datasets/{dataset}'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_workspace#dataset HealthcareWorkspace#dataset}
    */
    readonly dataset: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_workspace#id HealthcareWorkspace#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The user labels. An object containing a list of "key": value pairs. Example: { "name": "wrench", "mass": "1.3kg", "count": "3" }
    *
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_workspace#labels HealthcareWorkspace#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The name of the workspace, in the format 'projects/{projectId}/locations/{location}/datasets/{datasetId}/dataMapperWorkspaces/{workspaceId}'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_workspace#name HealthcareWorkspace#name}
    */
    readonly name: string;
    /**
    * settings block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_workspace#settings HealthcareWorkspace#settings}
    */
    readonly settings: HealthcareWorkspaceSettings;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_workspace#timeouts HealthcareWorkspace#timeouts}
    */
    readonly timeouts?: HealthcareWorkspaceTimeouts;
}
export interface HealthcareWorkspaceSettings {
    /**
    * Project IDs for data projects hosted in a workspace.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_workspace#data_project_ids HealthcareWorkspace#data_project_ids}
    */
    readonly dataProjectIds: string[];
}
export declare function healthcareWorkspaceSettingsToTerraform(struct?: HealthcareWorkspaceSettingsOutputReference | HealthcareWorkspaceSettings): any;
export declare function healthcareWorkspaceSettingsToHclTerraform(struct?: HealthcareWorkspaceSettingsOutputReference | HealthcareWorkspaceSettings): any;
export declare class HealthcareWorkspaceSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): HealthcareWorkspaceSettings | undefined;
    set internalValue(value: HealthcareWorkspaceSettings | undefined);
    private _dataProjectIds?;
    get dataProjectIds(): string[];
    set dataProjectIds(value: string[]);
    get dataProjectIdsInput(): string[] | undefined;
}
export interface HealthcareWorkspaceTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_workspace#create HealthcareWorkspace#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_workspace#delete HealthcareWorkspace#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_workspace#update HealthcareWorkspace#update}
    */
    readonly update?: string;
}
export declare function healthcareWorkspaceTimeoutsToTerraform(struct?: HealthcareWorkspaceTimeouts | cdktf.IResolvable): any;
export declare function healthcareWorkspaceTimeoutsToHclTerraform(struct?: HealthcareWorkspaceTimeouts | cdktf.IResolvable): any;
export declare class HealthcareWorkspaceTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): HealthcareWorkspaceTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: HealthcareWorkspaceTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_workspace google_healthcare_workspace}
*/
export declare class HealthcareWorkspace extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_healthcare_workspace";
    /**
    * Generates CDKTF code for importing a HealthcareWorkspace resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the HealthcareWorkspace to import
    * @param importFromId The id of the existing HealthcareWorkspace that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_workspace#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the HealthcareWorkspace to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/healthcare_workspace google_healthcare_workspace} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options HealthcareWorkspaceConfig
    */
    constructor(scope: Construct, id: string, config: HealthcareWorkspaceConfig);
    private _dataset?;
    get dataset(): string;
    set dataset(value: string);
    get datasetInput(): string | undefined;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    private _settings;
    get settings(): HealthcareWorkspaceSettingsOutputReference;
    putSettings(value: HealthcareWorkspaceSettings): void;
    get settingsInput(): HealthcareWorkspaceSettings | undefined;
    private _timeouts;
    get timeouts(): HealthcareWorkspaceTimeoutsOutputReference;
    putTimeouts(value: HealthcareWorkspaceTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | HealthcareWorkspaceTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
