/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NetworkConnectivityGroupConfig extends cdktf.TerraformMetaArguments {
    /**
    * An optional description of the group.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/network_connectivity_group#description NetworkConnectivityGroup#description}
    */
    readonly description?: string;
    /**
    * The name of the hub. Hub names must be unique. They use the following form: projects/{projectNumber}/locations/global/hubs/{hubId}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/network_connectivity_group#hub NetworkConnectivityGroup#hub}
    */
    readonly hub: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/network_connectivity_group#id NetworkConnectivityGroup#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Optional labels in key:value format. For more information about labels, see [Requirements for labels](https://cloud.google.com/resource-manager/docs/creating-managing-labels#requirements).
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/network_connectivity_group#labels NetworkConnectivityGroup#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The name of the group. Group names must be unique. Possible values: ["default", "center", "edge"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/network_connectivity_group#name NetworkConnectivityGroup#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/network_connectivity_group#project NetworkConnectivityGroup#project}
    */
    readonly project?: string;
    /**
    * auto_accept block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/network_connectivity_group#auto_accept NetworkConnectivityGroup#auto_accept}
    */
    readonly autoAccept?: NetworkConnectivityGroupAutoAccept;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/network_connectivity_group#timeouts NetworkConnectivityGroup#timeouts}
    */
    readonly timeouts?: NetworkConnectivityGroupTimeouts;
}
export interface NetworkConnectivityGroupAutoAccept {
    /**
    * A list of project ids or project numbers for which you want to enable auto-accept. The auto-accept setting is applied to spokes being created or updated in these projects.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/network_connectivity_group#auto_accept_projects NetworkConnectivityGroup#auto_accept_projects}
    */
    readonly autoAcceptProjects: string[];
}
export declare function networkConnectivityGroupAutoAcceptToTerraform(struct?: NetworkConnectivityGroupAutoAcceptOutputReference | NetworkConnectivityGroupAutoAccept): any;
export declare function networkConnectivityGroupAutoAcceptToHclTerraform(struct?: NetworkConnectivityGroupAutoAcceptOutputReference | NetworkConnectivityGroupAutoAccept): any;
export declare class NetworkConnectivityGroupAutoAcceptOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NetworkConnectivityGroupAutoAccept | undefined;
    set internalValue(value: NetworkConnectivityGroupAutoAccept | undefined);
    private _autoAcceptProjects?;
    get autoAcceptProjects(): string[];
    set autoAcceptProjects(value: string[]);
    get autoAcceptProjectsInput(): string[] | undefined;
}
export interface NetworkConnectivityGroupTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/network_connectivity_group#create NetworkConnectivityGroup#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/network_connectivity_group#delete NetworkConnectivityGroup#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/network_connectivity_group#update NetworkConnectivityGroup#update}
    */
    readonly update?: string;
}
export declare function networkConnectivityGroupTimeoutsToTerraform(struct?: NetworkConnectivityGroupTimeouts | cdktf.IResolvable): any;
export declare function networkConnectivityGroupTimeoutsToHclTerraform(struct?: NetworkConnectivityGroupTimeouts | cdktf.IResolvable): any;
export declare class NetworkConnectivityGroupTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NetworkConnectivityGroupTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: NetworkConnectivityGroupTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/network_connectivity_group google_network_connectivity_group}
*/
export declare class NetworkConnectivityGroup extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_network_connectivity_group";
    /**
    * Generates CDKTF code for importing a NetworkConnectivityGroup resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NetworkConnectivityGroup to import
    * @param importFromId The id of the existing NetworkConnectivityGroup that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/network_connectivity_group#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NetworkConnectivityGroup to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/network_connectivity_group google_network_connectivity_group} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NetworkConnectivityGroupConfig
    */
    constructor(scope: Construct, id: string, config: NetworkConnectivityGroupConfig);
    get createTime(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _hub?;
    get hub(): string;
    set hub(value: string);
    get hubInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get routeTable(): string;
    get state(): string;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get uid(): string;
    get updateTime(): string;
    private _autoAccept;
    get autoAccept(): NetworkConnectivityGroupAutoAcceptOutputReference;
    putAutoAccept(value: NetworkConnectivityGroupAutoAccept): void;
    resetAutoAccept(): void;
    get autoAcceptInput(): NetworkConnectivityGroupAutoAccept | undefined;
    private _timeouts;
    get timeouts(): NetworkConnectivityGroupTimeoutsOutputReference;
    putTimeouts(value: NetworkConnectivityGroupTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | NetworkConnectivityGroupTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
