/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface OracleDatabaseAutonomousDatabaseConfig extends cdktf.TerraformMetaArguments {
    /**
    * The password for the default ADMIN user.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#admin_password OracleDatabaseAutonomousDatabase#admin_password}
    */
    readonly adminPassword?: string;
    /**
    * The ID of the Autonomous Database to create. This value is restricted
    * to (^[a-z]([a-z0-9-]{0,61}[a-z0-9])?$) and must be a maximum of 63
    * characters in length. The value must start with a letter and end with
    * a letter or a number.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#autonomous_database_id OracleDatabaseAutonomousDatabase#autonomous_database_id}
    */
    readonly autonomousDatabaseId: string;
    /**
    * The subnet CIDR range for the Autonmous Database.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#cidr OracleDatabaseAutonomousDatabase#cidr}
    */
    readonly cidr: string;
    /**
    * The name of the Autonomous Database. The database name must be unique in
    * the project. The name must begin with a letter and can
    * contain a maximum of 30 alphanumeric characters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#database OracleDatabaseAutonomousDatabase#database}
    */
    readonly database: string;
    /**
    * The display name for the Autonomous Database. The name does not have to
    * be unique within your project.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#display_name OracleDatabaseAutonomousDatabase#display_name}
    */
    readonly displayName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#id OracleDatabaseAutonomousDatabase#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The labels or tags associated with the Autonomous Database.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#labels OracleDatabaseAutonomousDatabase#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Resource ID segment making up resource 'name'. See documentation for resource type 'oracledatabase.googleapis.com/AutonomousDatabaseBackup'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#location OracleDatabaseAutonomousDatabase#location}
    */
    readonly location: string;
    /**
    * The name of the VPC network used by the Autonomous Database.
    * Format: projects/{project}/global/networks/{network}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#network OracleDatabaseAutonomousDatabase#network}
    */
    readonly network: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#project OracleDatabaseAutonomousDatabase#project}
    */
    readonly project?: string;
    /**
    * properties block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#properties OracleDatabaseAutonomousDatabase#properties}
    */
    readonly properties: OracleDatabaseAutonomousDatabaseProperties;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#timeouts OracleDatabaseAutonomousDatabase#timeouts}
    */
    readonly timeouts?: OracleDatabaseAutonomousDatabaseTimeouts;
}
export interface OracleDatabaseAutonomousDatabasePropertiesApexDetails {
}
export declare function oracleDatabaseAutonomousDatabasePropertiesApexDetailsToTerraform(struct?: OracleDatabaseAutonomousDatabasePropertiesApexDetails): any;
export declare function oracleDatabaseAutonomousDatabasePropertiesApexDetailsToHclTerraform(struct?: OracleDatabaseAutonomousDatabasePropertiesApexDetails): any;
export declare class OracleDatabaseAutonomousDatabasePropertiesApexDetailsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): OracleDatabaseAutonomousDatabasePropertiesApexDetails | undefined;
    set internalValue(value: OracleDatabaseAutonomousDatabasePropertiesApexDetails | undefined);
    get apexVersion(): string;
    get ordsVersion(): string;
}
export declare class OracleDatabaseAutonomousDatabasePropertiesApexDetailsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): OracleDatabaseAutonomousDatabasePropertiesApexDetailsOutputReference;
}
export interface OracleDatabaseAutonomousDatabasePropertiesConnectionStringsAllConnectionStrings {
}
export declare function oracleDatabaseAutonomousDatabasePropertiesConnectionStringsAllConnectionStringsToTerraform(struct?: OracleDatabaseAutonomousDatabasePropertiesConnectionStringsAllConnectionStrings): any;
export declare function oracleDatabaseAutonomousDatabasePropertiesConnectionStringsAllConnectionStringsToHclTerraform(struct?: OracleDatabaseAutonomousDatabasePropertiesConnectionStringsAllConnectionStrings): any;
export declare class OracleDatabaseAutonomousDatabasePropertiesConnectionStringsAllConnectionStringsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): OracleDatabaseAutonomousDatabasePropertiesConnectionStringsAllConnectionStrings | undefined;
    set internalValue(value: OracleDatabaseAutonomousDatabasePropertiesConnectionStringsAllConnectionStrings | undefined);
    get high(): string;
    get low(): string;
    get medium(): string;
}
export declare class OracleDatabaseAutonomousDatabasePropertiesConnectionStringsAllConnectionStringsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): OracleDatabaseAutonomousDatabasePropertiesConnectionStringsAllConnectionStringsOutputReference;
}
export interface OracleDatabaseAutonomousDatabasePropertiesConnectionStringsProfiles {
}
export declare function oracleDatabaseAutonomousDatabasePropertiesConnectionStringsProfilesToTerraform(struct?: OracleDatabaseAutonomousDatabasePropertiesConnectionStringsProfiles): any;
export declare function oracleDatabaseAutonomousDatabasePropertiesConnectionStringsProfilesToHclTerraform(struct?: OracleDatabaseAutonomousDatabasePropertiesConnectionStringsProfiles): any;
export declare class OracleDatabaseAutonomousDatabasePropertiesConnectionStringsProfilesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): OracleDatabaseAutonomousDatabasePropertiesConnectionStringsProfiles | undefined;
    set internalValue(value: OracleDatabaseAutonomousDatabasePropertiesConnectionStringsProfiles | undefined);
    get consumerGroup(): string;
    get displayName(): string;
    get hostFormat(): string;
    get isRegional(): cdktf.IResolvable;
    get protocol(): string;
    get sessionMode(): string;
    get syntaxFormat(): string;
    get tlsAuthentication(): string;
    get value(): string;
}
export declare class OracleDatabaseAutonomousDatabasePropertiesConnectionStringsProfilesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): OracleDatabaseAutonomousDatabasePropertiesConnectionStringsProfilesOutputReference;
}
export interface OracleDatabaseAutonomousDatabasePropertiesConnectionStrings {
}
export declare function oracleDatabaseAutonomousDatabasePropertiesConnectionStringsToTerraform(struct?: OracleDatabaseAutonomousDatabasePropertiesConnectionStrings): any;
export declare function oracleDatabaseAutonomousDatabasePropertiesConnectionStringsToHclTerraform(struct?: OracleDatabaseAutonomousDatabasePropertiesConnectionStrings): any;
export declare class OracleDatabaseAutonomousDatabasePropertiesConnectionStringsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): OracleDatabaseAutonomousDatabasePropertiesConnectionStrings | undefined;
    set internalValue(value: OracleDatabaseAutonomousDatabasePropertiesConnectionStrings | undefined);
    private _allConnectionStrings;
    get allConnectionStrings(): OracleDatabaseAutonomousDatabasePropertiesConnectionStringsAllConnectionStringsList;
    get dedicated(): string;
    get high(): string;
    get low(): string;
    get medium(): string;
    private _profiles;
    get profiles(): OracleDatabaseAutonomousDatabasePropertiesConnectionStringsProfilesList;
}
export declare class OracleDatabaseAutonomousDatabasePropertiesConnectionStringsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): OracleDatabaseAutonomousDatabasePropertiesConnectionStringsOutputReference;
}
export interface OracleDatabaseAutonomousDatabasePropertiesConnectionUrls {
}
export declare function oracleDatabaseAutonomousDatabasePropertiesConnectionUrlsToTerraform(struct?: OracleDatabaseAutonomousDatabasePropertiesConnectionUrls): any;
export declare function oracleDatabaseAutonomousDatabasePropertiesConnectionUrlsToHclTerraform(struct?: OracleDatabaseAutonomousDatabasePropertiesConnectionUrls): any;
export declare class OracleDatabaseAutonomousDatabasePropertiesConnectionUrlsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): OracleDatabaseAutonomousDatabasePropertiesConnectionUrls | undefined;
    set internalValue(value: OracleDatabaseAutonomousDatabasePropertiesConnectionUrls | undefined);
    get apexUri(): string;
    get databaseTransformsUri(): string;
    get graphStudioUri(): string;
    get machineLearningNotebookUri(): string;
    get machineLearningUserManagementUri(): string;
    get mongoDbUri(): string;
    get ordsUri(): string;
    get sqlDevWebUri(): string;
}
export declare class OracleDatabaseAutonomousDatabasePropertiesConnectionUrlsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): OracleDatabaseAutonomousDatabasePropertiesConnectionUrlsOutputReference;
}
export interface OracleDatabaseAutonomousDatabasePropertiesLocalStandbyDb {
}
export declare function oracleDatabaseAutonomousDatabasePropertiesLocalStandbyDbToTerraform(struct?: OracleDatabaseAutonomousDatabasePropertiesLocalStandbyDb): any;
export declare function oracleDatabaseAutonomousDatabasePropertiesLocalStandbyDbToHclTerraform(struct?: OracleDatabaseAutonomousDatabasePropertiesLocalStandbyDb): any;
export declare class OracleDatabaseAutonomousDatabasePropertiesLocalStandbyDbOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): OracleDatabaseAutonomousDatabasePropertiesLocalStandbyDb | undefined;
    set internalValue(value: OracleDatabaseAutonomousDatabasePropertiesLocalStandbyDb | undefined);
    get dataGuardRoleChangedTime(): string;
    get disasterRecoveryRoleChangedTime(): string;
    get lagTimeDuration(): string;
    get lifecycleDetails(): string;
    get state(): string;
}
export declare class OracleDatabaseAutonomousDatabasePropertiesLocalStandbyDbList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): OracleDatabaseAutonomousDatabasePropertiesLocalStandbyDbOutputReference;
}
export interface OracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStartTime {
}
export declare function oracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStartTimeToTerraform(struct?: OracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStartTime): any;
export declare function oracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStartTimeToHclTerraform(struct?: OracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStartTime): any;
export declare class OracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStartTimeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): OracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStartTime | undefined;
    set internalValue(value: OracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStartTime | undefined);
    get hours(): number;
    get minutes(): number;
    get nanos(): number;
    get seconds(): number;
}
export declare class OracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStartTimeList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): OracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStartTimeOutputReference;
}
export interface OracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStopTime {
}
export declare function oracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStopTimeToTerraform(struct?: OracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStopTime): any;
export declare function oracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStopTimeToHclTerraform(struct?: OracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStopTime): any;
export declare class OracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStopTimeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): OracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStopTime | undefined;
    set internalValue(value: OracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStopTime | undefined);
    get hours(): number;
    get minutes(): number;
    get nanos(): number;
    get seconds(): number;
}
export declare class OracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStopTimeList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): OracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStopTimeOutputReference;
}
export interface OracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetails {
}
export declare function oracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsToTerraform(struct?: OracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetails): any;
export declare function oracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsToHclTerraform(struct?: OracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetails): any;
export declare class OracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): OracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetails | undefined;
    set internalValue(value: OracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetails | undefined);
    get dayOfWeek(): string;
    private _startTime;
    get startTime(): OracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStartTimeList;
    private _stopTime;
    get stopTime(): OracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStopTimeList;
}
export declare class OracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): OracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsOutputReference;
}
export interface OracleDatabaseAutonomousDatabasePropertiesCustomerContacts {
    /**
    * The email address used by Oracle to send notifications regarding databases
    * and infrastructure.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#email OracleDatabaseAutonomousDatabase#email}
    */
    readonly email: string;
}
export declare function oracleDatabaseAutonomousDatabasePropertiesCustomerContactsToTerraform(struct?: OracleDatabaseAutonomousDatabasePropertiesCustomerContacts | cdktf.IResolvable): any;
export declare function oracleDatabaseAutonomousDatabasePropertiesCustomerContactsToHclTerraform(struct?: OracleDatabaseAutonomousDatabasePropertiesCustomerContacts | cdktf.IResolvable): any;
export declare class OracleDatabaseAutonomousDatabasePropertiesCustomerContactsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): OracleDatabaseAutonomousDatabasePropertiesCustomerContacts | cdktf.IResolvable | undefined;
    set internalValue(value: OracleDatabaseAutonomousDatabasePropertiesCustomerContacts | cdktf.IResolvable | undefined);
    private _email?;
    get email(): string;
    set email(value: string);
    get emailInput(): string | undefined;
}
export declare class OracleDatabaseAutonomousDatabasePropertiesCustomerContactsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: OracleDatabaseAutonomousDatabasePropertiesCustomerContacts[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): OracleDatabaseAutonomousDatabasePropertiesCustomerContactsOutputReference;
}
export interface OracleDatabaseAutonomousDatabaseProperties {
    /**
    * The retention period for the Autonomous Database. This field is specified
    * in days, can range from 1 day to 60 days, and has a default value of
    * 60 days.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#backup_retention_period_days OracleDatabaseAutonomousDatabase#backup_retention_period_days}
    */
    readonly backupRetentionPeriodDays?: number;
    /**
    * The character set for the Autonomous Database. The default is AL32UTF8.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#character_set OracleDatabaseAutonomousDatabase#character_set}
    */
    readonly characterSet?: string;
    /**
    * The number of compute servers for the Autonomous Database.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#compute_count OracleDatabaseAutonomousDatabase#compute_count}
    */
    readonly computeCount?: number;
    /**
    * The size of the data stored in the database, in gigabytes.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#data_storage_size_gb OracleDatabaseAutonomousDatabase#data_storage_size_gb}
    */
    readonly dataStorageSizeGb?: number;
    /**
    * The size of the data stored in the database, in terabytes.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#data_storage_size_tb OracleDatabaseAutonomousDatabase#data_storage_size_tb}
    */
    readonly dataStorageSizeTb?: number;
    /**
    * The edition of the Autonomous Databases.
    *  Possible values:
    *  DATABASE_EDITION_UNSPECIFIED
    * STANDARD_EDITION
    * ENTERPRISE_EDITION
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#db_edition OracleDatabaseAutonomousDatabase#db_edition}
    */
    readonly dbEdition?: string;
    /**
    * The Oracle Database version for the Autonomous Database.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#db_version OracleDatabaseAutonomousDatabase#db_version}
    */
    readonly dbVersion?: string;
    /**
    * Possible values:
    *  DB_WORKLOAD_UNSPECIFIED
    * OLTP
    * DW
    * AJD
    * APEX
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#db_workload OracleDatabaseAutonomousDatabase#db_workload}
    */
    readonly dbWorkload: string;
    /**
    * This field indicates if auto scaling is enabled for the Autonomous Database
    * CPU core count.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#is_auto_scaling_enabled OracleDatabaseAutonomousDatabase#is_auto_scaling_enabled}
    */
    readonly isAutoScalingEnabled?: boolean | cdktf.IResolvable;
    /**
    * This field indicates if auto scaling is enabled for the Autonomous Database
    * storage.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#is_storage_auto_scaling_enabled OracleDatabaseAutonomousDatabase#is_storage_auto_scaling_enabled}
    */
    readonly isStorageAutoScalingEnabled?: boolean | cdktf.IResolvable;
    /**
    * The license type used for the Autonomous Database.
    *  Possible values:
    *  LICENSE_TYPE_UNSPECIFIED
    * LICENSE_INCLUDED
    * BRING_YOUR_OWN_LICENSE
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#license_type OracleDatabaseAutonomousDatabase#license_type}
    */
    readonly licenseType: string;
    /**
    * The maintenance schedule of the Autonomous Database.
    *  Possible values:
    *  MAINTENANCE_SCHEDULE_TYPE_UNSPECIFIED
    * EARLY
    * REGULAR
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#maintenance_schedule_type OracleDatabaseAutonomousDatabase#maintenance_schedule_type}
    */
    readonly maintenanceScheduleType?: string;
    /**
    * This field specifies if the Autonomous Database requires mTLS connections.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#mtls_connection_required OracleDatabaseAutonomousDatabase#mtls_connection_required}
    */
    readonly mtlsConnectionRequired?: boolean | cdktf.IResolvable;
    /**
    * The national character set for the Autonomous Database. The default is
    * AL16UTF16.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#n_character_set OracleDatabaseAutonomousDatabase#n_character_set}
    */
    readonly nCharacterSet?: string;
    /**
    * Possible values:
    *  OPERATIONS_INSIGHTS_STATE_UNSPECIFIED
    * ENABLING
    * ENABLED
    * DISABLING
    * NOT_ENABLED
    * FAILED_ENABLING
    * FAILED_DISABLING
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#operations_insights_state OracleDatabaseAutonomousDatabase#operations_insights_state}
    */
    readonly operationsInsightsState?: string;
    /**
    * The private endpoint IP address for the Autonomous Database.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#private_endpoint_ip OracleDatabaseAutonomousDatabase#private_endpoint_ip}
    */
    readonly privateEndpointIp?: string;
    /**
    * The private endpoint label for the Autonomous Database.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#private_endpoint_label OracleDatabaseAutonomousDatabase#private_endpoint_label}
    */
    readonly privateEndpointLabel?: string;
    /**
    * customer_contacts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#customer_contacts OracleDatabaseAutonomousDatabase#customer_contacts}
    */
    readonly customerContacts?: OracleDatabaseAutonomousDatabasePropertiesCustomerContacts[] | cdktf.IResolvable;
}
export declare function oracleDatabaseAutonomousDatabasePropertiesToTerraform(struct?: OracleDatabaseAutonomousDatabasePropertiesOutputReference | OracleDatabaseAutonomousDatabaseProperties): any;
export declare function oracleDatabaseAutonomousDatabasePropertiesToHclTerraform(struct?: OracleDatabaseAutonomousDatabasePropertiesOutputReference | OracleDatabaseAutonomousDatabaseProperties): any;
export declare class OracleDatabaseAutonomousDatabasePropertiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): OracleDatabaseAutonomousDatabaseProperties | undefined;
    set internalValue(value: OracleDatabaseAutonomousDatabaseProperties | undefined);
    get actualUsedDataStorageSizeTb(): number;
    get allocatedStorageSizeTb(): number;
    private _apexDetails;
    get apexDetails(): OracleDatabaseAutonomousDatabasePropertiesApexDetailsList;
    get arePrimaryAllowlistedIpsUsed(): cdktf.IResolvable;
    get autonomousContainerDatabaseId(): string;
    get availableUpgradeVersions(): string[];
    private _backupRetentionPeriodDays?;
    get backupRetentionPeriodDays(): number;
    set backupRetentionPeriodDays(value: number);
    resetBackupRetentionPeriodDays(): void;
    get backupRetentionPeriodDaysInput(): number | undefined;
    private _characterSet?;
    get characterSet(): string;
    set characterSet(value: string);
    resetCharacterSet(): void;
    get characterSetInput(): string | undefined;
    private _computeCount?;
    get computeCount(): number;
    set computeCount(value: number);
    resetComputeCount(): void;
    get computeCountInput(): number | undefined;
    private _connectionStrings;
    get connectionStrings(): OracleDatabaseAutonomousDatabasePropertiesConnectionStringsList;
    private _connectionUrls;
    get connectionUrls(): OracleDatabaseAutonomousDatabasePropertiesConnectionUrlsList;
    get dataSafeState(): string;
    private _dataStorageSizeGb?;
    get dataStorageSizeGb(): number;
    set dataStorageSizeGb(value: number);
    resetDataStorageSizeGb(): void;
    get dataStorageSizeGbInput(): number | undefined;
    private _dataStorageSizeTb?;
    get dataStorageSizeTb(): number;
    set dataStorageSizeTb(value: number);
    resetDataStorageSizeTb(): void;
    get dataStorageSizeTbInput(): number | undefined;
    get databaseManagementState(): string;
    private _dbEdition?;
    get dbEdition(): string;
    set dbEdition(value: string);
    resetDbEdition(): void;
    get dbEditionInput(): string | undefined;
    private _dbVersion?;
    get dbVersion(): string;
    set dbVersion(value: string);
    resetDbVersion(): void;
    get dbVersionInput(): string | undefined;
    private _dbWorkload?;
    get dbWorkload(): string;
    set dbWorkload(value: string);
    get dbWorkloadInput(): string | undefined;
    get failedDataRecoveryDuration(): string;
    private _isAutoScalingEnabled?;
    get isAutoScalingEnabled(): boolean | cdktf.IResolvable;
    set isAutoScalingEnabled(value: boolean | cdktf.IResolvable);
    resetIsAutoScalingEnabled(): void;
    get isAutoScalingEnabledInput(): boolean | cdktf.IResolvable | undefined;
    get isLocalDataGuardEnabled(): cdktf.IResolvable;
    private _isStorageAutoScalingEnabled?;
    get isStorageAutoScalingEnabled(): boolean | cdktf.IResolvable;
    set isStorageAutoScalingEnabled(value: boolean | cdktf.IResolvable);
    resetIsStorageAutoScalingEnabled(): void;
    get isStorageAutoScalingEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _licenseType?;
    get licenseType(): string;
    set licenseType(value: string);
    get licenseTypeInput(): string | undefined;
    get lifecycleDetails(): string;
    get localAdgAutoFailoverMaxDataLossLimit(): number;
    get localDisasterRecoveryType(): string;
    private _localStandbyDb;
    get localStandbyDb(): OracleDatabaseAutonomousDatabasePropertiesLocalStandbyDbList;
    get maintenanceBeginTime(): string;
    get maintenanceEndTime(): string;
    private _maintenanceScheduleType?;
    get maintenanceScheduleType(): string;
    set maintenanceScheduleType(value: string);
    resetMaintenanceScheduleType(): void;
    get maintenanceScheduleTypeInput(): string | undefined;
    get memoryPerOracleComputeUnitGbs(): number;
    get memoryTableGbs(): number;
    private _mtlsConnectionRequired?;
    get mtlsConnectionRequired(): boolean | cdktf.IResolvable;
    set mtlsConnectionRequired(value: boolean | cdktf.IResolvable);
    resetMtlsConnectionRequired(): void;
    get mtlsConnectionRequiredInput(): boolean | cdktf.IResolvable | undefined;
    private _nCharacterSet?;
    get nCharacterSet(): string;
    set nCharacterSet(value: string);
    resetNCharacterSet(): void;
    get nCharacterSetInput(): string | undefined;
    get nextLongTermBackupTime(): string;
    get ociUrl(): string;
    get ocid(): string;
    get openMode(): string;
    private _operationsInsightsState?;
    get operationsInsightsState(): string;
    set operationsInsightsState(value: string);
    resetOperationsInsightsState(): void;
    get operationsInsightsStateInput(): string | undefined;
    get peerDbIds(): string[];
    get permissionLevel(): string;
    get privateEndpoint(): string;
    private _privateEndpointIp?;
    get privateEndpointIp(): string;
    set privateEndpointIp(value: string);
    resetPrivateEndpointIp(): void;
    get privateEndpointIpInput(): string | undefined;
    private _privateEndpointLabel?;
    get privateEndpointLabel(): string;
    set privateEndpointLabel(value: string);
    resetPrivateEndpointLabel(): void;
    get privateEndpointLabelInput(): string | undefined;
    get refreshableMode(): string;
    get refreshableState(): string;
    get role(): string;
    private _scheduledOperationDetails;
    get scheduledOperationDetails(): OracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsList;
    get sqlWebDeveloperUrl(): string;
    get state(): string;
    get supportedCloneRegions(): string[];
    get totalAutoBackupStorageSizeGbs(): number;
    get usedDataStorageSizeTbs(): number;
    private _customerContacts;
    get customerContacts(): OracleDatabaseAutonomousDatabasePropertiesCustomerContactsList;
    putCustomerContacts(value: OracleDatabaseAutonomousDatabasePropertiesCustomerContacts[] | cdktf.IResolvable): void;
    resetCustomerContacts(): void;
    get customerContactsInput(): cdktf.IResolvable | OracleDatabaseAutonomousDatabasePropertiesCustomerContacts[] | undefined;
}
export interface OracleDatabaseAutonomousDatabaseTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#create OracleDatabaseAutonomousDatabase#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#delete OracleDatabaseAutonomousDatabase#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#update OracleDatabaseAutonomousDatabase#update}
    */
    readonly update?: string;
}
export declare function oracleDatabaseAutonomousDatabaseTimeoutsToTerraform(struct?: OracleDatabaseAutonomousDatabaseTimeouts | cdktf.IResolvable): any;
export declare function oracleDatabaseAutonomousDatabaseTimeoutsToHclTerraform(struct?: OracleDatabaseAutonomousDatabaseTimeouts | cdktf.IResolvable): any;
export declare class OracleDatabaseAutonomousDatabaseTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): OracleDatabaseAutonomousDatabaseTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: OracleDatabaseAutonomousDatabaseTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database google_oracle_database_autonomous_database}
*/
export declare class OracleDatabaseAutonomousDatabase extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_oracle_database_autonomous_database";
    /**
    * Generates CDKTF code for importing a OracleDatabaseAutonomousDatabase resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the OracleDatabaseAutonomousDatabase to import
    * @param importFromId The id of the existing OracleDatabaseAutonomousDatabase that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the OracleDatabaseAutonomousDatabase to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_autonomous_database google_oracle_database_autonomous_database} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options OracleDatabaseAutonomousDatabaseConfig
    */
    constructor(scope: Construct, id: string, config: OracleDatabaseAutonomousDatabaseConfig);
    private _adminPassword?;
    get adminPassword(): string;
    set adminPassword(value: string);
    resetAdminPassword(): void;
    get adminPasswordInput(): string | undefined;
    private _autonomousDatabaseId?;
    get autonomousDatabaseId(): string;
    set autonomousDatabaseId(value: string);
    get autonomousDatabaseIdInput(): string | undefined;
    private _cidr?;
    get cidr(): string;
    set cidr(value: string);
    get cidrInput(): string | undefined;
    get createTime(): string;
    private _database?;
    get database(): string;
    set database(value: string);
    get databaseInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    get entitlementId(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _network?;
    get network(): string;
    set network(value: string);
    get networkInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    private _properties;
    get properties(): OracleDatabaseAutonomousDatabasePropertiesOutputReference;
    putProperties(value: OracleDatabaseAutonomousDatabaseProperties): void;
    get propertiesInput(): OracleDatabaseAutonomousDatabaseProperties | undefined;
    private _timeouts;
    get timeouts(): OracleDatabaseAutonomousDatabaseTimeoutsOutputReference;
    putTimeouts(value: OracleDatabaseAutonomousDatabaseTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | OracleDatabaseAutonomousDatabaseTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
