/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface OracleDatabaseCloudExadataInfrastructureConfig extends cdktf.TerraformMetaArguments {
    /**
    * The ID of the Exadata Infrastructure to create. This value is restricted
    * to (^[a-z]([a-z0-9-]{0,61}[a-z0-9])?$) and must be a maximum of 63
    * characters in length. The value must start with a letter and end with
    * a letter or a number.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#cloud_exadata_infrastructure_id OracleDatabaseCloudExadataInfrastructure#cloud_exadata_infrastructure_id}
    */
    readonly cloudExadataInfrastructureId: string;
    /**
    * User friendly name for this resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#display_name OracleDatabaseCloudExadataInfrastructure#display_name}
    */
    readonly displayName?: string;
    /**
    * GCP location where Oracle Exadata is hosted.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#gcp_oracle_zone OracleDatabaseCloudExadataInfrastructure#gcp_oracle_zone}
    */
    readonly gcpOracleZone?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#id OracleDatabaseCloudExadataInfrastructure#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Labels or tags associated with the resource.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#labels OracleDatabaseCloudExadataInfrastructure#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Resource ID segment making up resource 'name'. See documentation for resource type 'oracledatabase.googleapis.com/DbServer'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#location OracleDatabaseCloudExadataInfrastructure#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#project OracleDatabaseCloudExadataInfrastructure#project}
    */
    readonly project?: string;
    /**
    * properties block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#properties OracleDatabaseCloudExadataInfrastructure#properties}
    */
    readonly properties?: OracleDatabaseCloudExadataInfrastructureProperties;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#timeouts OracleDatabaseCloudExadataInfrastructure#timeouts}
    */
    readonly timeouts?: OracleDatabaseCloudExadataInfrastructureTimeouts;
}
export interface OracleDatabaseCloudExadataInfrastructurePropertiesCustomerContacts {
    /**
    * The email address used by Oracle to send notifications regarding databases
    * and infrastructure.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#email OracleDatabaseCloudExadataInfrastructure#email}
    */
    readonly email: string;
}
export declare function oracleDatabaseCloudExadataInfrastructurePropertiesCustomerContactsToTerraform(struct?: OracleDatabaseCloudExadataInfrastructurePropertiesCustomerContacts | cdktf.IResolvable): any;
export declare function oracleDatabaseCloudExadataInfrastructurePropertiesCustomerContactsToHclTerraform(struct?: OracleDatabaseCloudExadataInfrastructurePropertiesCustomerContacts | cdktf.IResolvable): any;
export declare class OracleDatabaseCloudExadataInfrastructurePropertiesCustomerContactsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): OracleDatabaseCloudExadataInfrastructurePropertiesCustomerContacts | cdktf.IResolvable | undefined;
    set internalValue(value: OracleDatabaseCloudExadataInfrastructurePropertiesCustomerContacts | cdktf.IResolvable | undefined);
    private _email?;
    get email(): string;
    set email(value: string);
    get emailInput(): string | undefined;
}
export declare class OracleDatabaseCloudExadataInfrastructurePropertiesCustomerContactsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: OracleDatabaseCloudExadataInfrastructurePropertiesCustomerContacts[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): OracleDatabaseCloudExadataInfrastructurePropertiesCustomerContactsOutputReference;
}
export interface OracleDatabaseCloudExadataInfrastructurePropertiesMaintenanceWindow {
    /**
    * Determines the amount of time the system will wait before the start of each
    * database server patching operation. Custom action timeout is in minutes and
    * valid value is between 15 to 120 (inclusive).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#custom_action_timeout_mins OracleDatabaseCloudExadataInfrastructure#custom_action_timeout_mins}
    */
    readonly customActionTimeoutMins?: number;
    /**
    * Days during the week when maintenance should be performed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#days_of_week OracleDatabaseCloudExadataInfrastructure#days_of_week}
    */
    readonly daysOfWeek?: string[];
    /**
    * The window of hours during the day when maintenance should be performed.
    * The window is a 4 hour slot. Valid values are:
    *   0 - represents time slot 0:00 - 3:59 UTC
    *   4 - represents time slot 4:00 - 7:59 UTC
    *   8 - represents time slot 8:00 - 11:59 UTC
    *   12 - represents time slot 12:00 - 15:59 UTC
    *   16 - represents time slot 16:00 - 19:59 UTC
    *   20 - represents time slot 20:00 - 23:59 UTC
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#hours_of_day OracleDatabaseCloudExadataInfrastructure#hours_of_day}
    */
    readonly hoursOfDay?: number[];
    /**
    * If true, enables the configuration of a custom action timeout (waiting
    * period) between database server patching operations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#is_custom_action_timeout_enabled OracleDatabaseCloudExadataInfrastructure#is_custom_action_timeout_enabled}
    */
    readonly isCustomActionTimeoutEnabled?: boolean | cdktf.IResolvable;
    /**
    * Lead time window allows user to set a lead time to prepare for a down time.
    * The lead time is in weeks and valid value is between 1 to 4.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#lead_time_week OracleDatabaseCloudExadataInfrastructure#lead_time_week}
    */
    readonly leadTimeWeek?: number;
    /**
    * Months during the year when maintenance should be performed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#months OracleDatabaseCloudExadataInfrastructure#months}
    */
    readonly months?: string[];
    /**
    * Cloud CloudExadataInfrastructure node patching method, either "ROLLING"
    *  or "NONROLLING". Default value is ROLLING.
    *  Possible values:
    *  PATCHING_MODE_UNSPECIFIED
    * ROLLING
    * NON_ROLLING
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#patching_mode OracleDatabaseCloudExadataInfrastructure#patching_mode}
    */
    readonly patchingMode?: string;
    /**
    * The maintenance window scheduling preference.
    *  Possible values:
    *  MAINTENANCE_WINDOW_PREFERENCE_UNSPECIFIED
    * CUSTOM_PREFERENCE
    * NO_PREFERENCE
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#preference OracleDatabaseCloudExadataInfrastructure#preference}
    */
    readonly preference?: string;
    /**
    * Weeks during the month when maintenance should be performed. Weeks start on
    * the 1st, 8th, 15th, and 22nd days of the month, and have a duration of 7
    * days. Weeks start and end based on calendar dates, not days of the week.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#weeks_of_month OracleDatabaseCloudExadataInfrastructure#weeks_of_month}
    */
    readonly weeksOfMonth?: number[];
}
export declare function oracleDatabaseCloudExadataInfrastructurePropertiesMaintenanceWindowToTerraform(struct?: OracleDatabaseCloudExadataInfrastructurePropertiesMaintenanceWindowOutputReference | OracleDatabaseCloudExadataInfrastructurePropertiesMaintenanceWindow): any;
export declare function oracleDatabaseCloudExadataInfrastructurePropertiesMaintenanceWindowToHclTerraform(struct?: OracleDatabaseCloudExadataInfrastructurePropertiesMaintenanceWindowOutputReference | OracleDatabaseCloudExadataInfrastructurePropertiesMaintenanceWindow): any;
export declare class OracleDatabaseCloudExadataInfrastructurePropertiesMaintenanceWindowOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): OracleDatabaseCloudExadataInfrastructurePropertiesMaintenanceWindow | undefined;
    set internalValue(value: OracleDatabaseCloudExadataInfrastructurePropertiesMaintenanceWindow | undefined);
    private _customActionTimeoutMins?;
    get customActionTimeoutMins(): number;
    set customActionTimeoutMins(value: number);
    resetCustomActionTimeoutMins(): void;
    get customActionTimeoutMinsInput(): number | undefined;
    private _daysOfWeek?;
    get daysOfWeek(): string[];
    set daysOfWeek(value: string[]);
    resetDaysOfWeek(): void;
    get daysOfWeekInput(): string[] | undefined;
    private _hoursOfDay?;
    get hoursOfDay(): number[];
    set hoursOfDay(value: number[]);
    resetHoursOfDay(): void;
    get hoursOfDayInput(): number[] | undefined;
    private _isCustomActionTimeoutEnabled?;
    get isCustomActionTimeoutEnabled(): boolean | cdktf.IResolvable;
    set isCustomActionTimeoutEnabled(value: boolean | cdktf.IResolvable);
    resetIsCustomActionTimeoutEnabled(): void;
    get isCustomActionTimeoutEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _leadTimeWeek?;
    get leadTimeWeek(): number;
    set leadTimeWeek(value: number);
    resetLeadTimeWeek(): void;
    get leadTimeWeekInput(): number | undefined;
    private _months?;
    get months(): string[];
    set months(value: string[]);
    resetMonths(): void;
    get monthsInput(): string[] | undefined;
    private _patchingMode?;
    get patchingMode(): string;
    set patchingMode(value: string);
    resetPatchingMode(): void;
    get patchingModeInput(): string | undefined;
    private _preference?;
    get preference(): string;
    set preference(value: string);
    resetPreference(): void;
    get preferenceInput(): string | undefined;
    private _weeksOfMonth?;
    get weeksOfMonth(): number[];
    set weeksOfMonth(value: number[]);
    resetWeeksOfMonth(): void;
    get weeksOfMonthInput(): number[] | undefined;
}
export interface OracleDatabaseCloudExadataInfrastructureProperties {
    /**
    * The number of compute servers for the Exadata Infrastructure.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#compute_count OracleDatabaseCloudExadataInfrastructure#compute_count}
    */
    readonly computeCount?: number;
    /**
    * The shape of the Exadata Infrastructure. The shape determines the
    * amount of CPU, storage, and memory resources allocated to the instance.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#shape OracleDatabaseCloudExadataInfrastructure#shape}
    */
    readonly shape: string;
    /**
    * The number of Cloud Exadata storage servers for the Exadata Infrastructure.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#storage_count OracleDatabaseCloudExadataInfrastructure#storage_count}
    */
    readonly storageCount?: number;
    /**
    * The total storage allocated to the Exadata Infrastructure
    * resource, in gigabytes (GB).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#total_storage_size_gb OracleDatabaseCloudExadataInfrastructure#total_storage_size_gb}
    */
    readonly totalStorageSizeGb?: number;
    /**
    * customer_contacts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#customer_contacts OracleDatabaseCloudExadataInfrastructure#customer_contacts}
    */
    readonly customerContacts?: OracleDatabaseCloudExadataInfrastructurePropertiesCustomerContacts[] | cdktf.IResolvable;
    /**
    * maintenance_window block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#maintenance_window OracleDatabaseCloudExadataInfrastructure#maintenance_window}
    */
    readonly maintenanceWindow?: OracleDatabaseCloudExadataInfrastructurePropertiesMaintenanceWindow;
}
export declare function oracleDatabaseCloudExadataInfrastructurePropertiesToTerraform(struct?: OracleDatabaseCloudExadataInfrastructurePropertiesOutputReference | OracleDatabaseCloudExadataInfrastructureProperties): any;
export declare function oracleDatabaseCloudExadataInfrastructurePropertiesToHclTerraform(struct?: OracleDatabaseCloudExadataInfrastructurePropertiesOutputReference | OracleDatabaseCloudExadataInfrastructureProperties): any;
export declare class OracleDatabaseCloudExadataInfrastructurePropertiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): OracleDatabaseCloudExadataInfrastructureProperties | undefined;
    set internalValue(value: OracleDatabaseCloudExadataInfrastructureProperties | undefined);
    get activatedStorageCount(): number;
    get additionalStorageCount(): number;
    get availableStorageSizeGb(): number;
    private _computeCount?;
    get computeCount(): number;
    set computeCount(value: number);
    resetComputeCount(): void;
    get computeCountInput(): number | undefined;
    get cpuCount(): number;
    get dataStorageSizeTb(): number;
    get dbNodeStorageSizeGb(): number;
    get dbServerVersion(): string;
    get maxCpuCount(): number;
    get maxDataStorageTb(): number;
    get maxDbNodeStorageSizeGb(): number;
    get maxMemoryGb(): number;
    get memorySizeGb(): number;
    get monthlyDbServerVersion(): string;
    get monthlyStorageServerVersion(): string;
    get nextMaintenanceRunId(): string;
    get nextMaintenanceRunTime(): string;
    get nextSecurityMaintenanceRunTime(): string;
    get ociUrl(): string;
    get ocid(): string;
    private _shape?;
    get shape(): string;
    set shape(value: string);
    get shapeInput(): string | undefined;
    get state(): string;
    private _storageCount?;
    get storageCount(): number;
    set storageCount(value: number);
    resetStorageCount(): void;
    get storageCountInput(): number | undefined;
    get storageServerVersion(): string;
    private _totalStorageSizeGb?;
    get totalStorageSizeGb(): number;
    set totalStorageSizeGb(value: number);
    resetTotalStorageSizeGb(): void;
    get totalStorageSizeGbInput(): number | undefined;
    private _customerContacts;
    get customerContacts(): OracleDatabaseCloudExadataInfrastructurePropertiesCustomerContactsList;
    putCustomerContacts(value: OracleDatabaseCloudExadataInfrastructurePropertiesCustomerContacts[] | cdktf.IResolvable): void;
    resetCustomerContacts(): void;
    get customerContactsInput(): cdktf.IResolvable | OracleDatabaseCloudExadataInfrastructurePropertiesCustomerContacts[] | undefined;
    private _maintenanceWindow;
    get maintenanceWindow(): OracleDatabaseCloudExadataInfrastructurePropertiesMaintenanceWindowOutputReference;
    putMaintenanceWindow(value: OracleDatabaseCloudExadataInfrastructurePropertiesMaintenanceWindow): void;
    resetMaintenanceWindow(): void;
    get maintenanceWindowInput(): OracleDatabaseCloudExadataInfrastructurePropertiesMaintenanceWindow | undefined;
}
export interface OracleDatabaseCloudExadataInfrastructureTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#create OracleDatabaseCloudExadataInfrastructure#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#delete OracleDatabaseCloudExadataInfrastructure#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#update OracleDatabaseCloudExadataInfrastructure#update}
    */
    readonly update?: string;
}
export declare function oracleDatabaseCloudExadataInfrastructureTimeoutsToTerraform(struct?: OracleDatabaseCloudExadataInfrastructureTimeouts | cdktf.IResolvable): any;
export declare function oracleDatabaseCloudExadataInfrastructureTimeoutsToHclTerraform(struct?: OracleDatabaseCloudExadataInfrastructureTimeouts | cdktf.IResolvable): any;
export declare class OracleDatabaseCloudExadataInfrastructureTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): OracleDatabaseCloudExadataInfrastructureTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: OracleDatabaseCloudExadataInfrastructureTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure google_oracle_database_cloud_exadata_infrastructure}
*/
export declare class OracleDatabaseCloudExadataInfrastructure extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_oracle_database_cloud_exadata_infrastructure";
    /**
    * Generates CDKTF code for importing a OracleDatabaseCloudExadataInfrastructure resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the OracleDatabaseCloudExadataInfrastructure to import
    * @param importFromId The id of the existing OracleDatabaseCloudExadataInfrastructure that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the OracleDatabaseCloudExadataInfrastructure to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/oracle_database_cloud_exadata_infrastructure google_oracle_database_cloud_exadata_infrastructure} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options OracleDatabaseCloudExadataInfrastructureConfig
    */
    constructor(scope: Construct, id: string, config: OracleDatabaseCloudExadataInfrastructureConfig);
    private _cloudExadataInfrastructureId?;
    get cloudExadataInfrastructureId(): string;
    set cloudExadataInfrastructureId(value: string);
    get cloudExadataInfrastructureIdInput(): string | undefined;
    get createTime(): string;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    get entitlementId(): string;
    private _gcpOracleZone?;
    get gcpOracleZone(): string;
    set gcpOracleZone(value: string);
    resetGcpOracleZone(): void;
    get gcpOracleZoneInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    private _properties;
    get properties(): OracleDatabaseCloudExadataInfrastructurePropertiesOutputReference;
    putProperties(value: OracleDatabaseCloudExadataInfrastructureProperties): void;
    resetProperties(): void;
    get propertiesInput(): OracleDatabaseCloudExadataInfrastructureProperties | undefined;
    private _timeouts;
    get timeouts(): OracleDatabaseCloudExadataInfrastructureTimeoutsOutputReference;
    putTimeouts(value: OracleDatabaseCloudExadataInfrastructureTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | OracleDatabaseCloudExadataInfrastructureTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
