/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface SccFolderSccBigQueryExportConfig extends cdktf.TerraformMetaArguments {
    /**
    * This must be unique within the organization.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/scc_folder_scc_big_query_export#big_query_export_id SccFolderSccBigQueryExport#big_query_export_id}
    */
    readonly bigQueryExportId: string;
    /**
    * The dataset to write findings' updates to.
    * Its format is "projects/[projectId]/datasets/[bigquery_dataset_id]".
    * BigQuery Dataset unique ID must contain only letters (a-z, A-Z), numbers (0-9), or underscores (_).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/scc_folder_scc_big_query_export#dataset SccFolderSccBigQueryExport#dataset}
    */
    readonly dataset: string;
    /**
    * The description of the export (max of 1024 characters).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/scc_folder_scc_big_query_export#description SccFolderSccBigQueryExport#description}
    */
    readonly description: string;
    /**
    * Expression that defines the filter to apply across create/update
    * events of findings. The
    * expression is a list of zero or more restrictions combined via
    * logical operators AND and OR. Parentheses are supported, and OR
    * has higher precedence than AND.
    *
    * Restrictions have the form <field> <operator> <value> and may have
    * a - character in front of them to indicate negation. The fields
    * map to those defined in the corresponding resource.
    *
    * The supported operators are:
    *
    * * = for all value types.
    * * >, <, >=, <= for integer values.
    * * :, meaning substring matching, for strings.
    *
    * The supported value types are:
    *
    * * string literals in quotes.
    * * integer literals without quotes.
    * * boolean literals true and false without quotes.
    *
    * See
    * [Filtering notifications](https://cloud.google.com/security-command-center/docs/how-to-api-filter-notifications)
    * for information on how to write a filter.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/scc_folder_scc_big_query_export#filter SccFolderSccBigQueryExport#filter}
    */
    readonly filter: string;
    /**
    * The folder where Cloud Security Command Center Big Query Export
    * Config lives in.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/scc_folder_scc_big_query_export#folder SccFolderSccBigQueryExport#folder}
    */
    readonly folder: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/scc_folder_scc_big_query_export#id SccFolderSccBigQueryExport#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/scc_folder_scc_big_query_export#timeouts SccFolderSccBigQueryExport#timeouts}
    */
    readonly timeouts?: SccFolderSccBigQueryExportTimeouts;
}
export interface SccFolderSccBigQueryExportTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/scc_folder_scc_big_query_export#create SccFolderSccBigQueryExport#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/scc_folder_scc_big_query_export#delete SccFolderSccBigQueryExport#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/scc_folder_scc_big_query_export#update SccFolderSccBigQueryExport#update}
    */
    readonly update?: string;
}
export declare function sccFolderSccBigQueryExportTimeoutsToTerraform(struct?: SccFolderSccBigQueryExportTimeouts | cdktf.IResolvable): any;
export declare function sccFolderSccBigQueryExportTimeoutsToHclTerraform(struct?: SccFolderSccBigQueryExportTimeouts | cdktf.IResolvable): any;
export declare class SccFolderSccBigQueryExportTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SccFolderSccBigQueryExportTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: SccFolderSccBigQueryExportTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/scc_folder_scc_big_query_export google_scc_folder_scc_big_query_export}
*/
export declare class SccFolderSccBigQueryExport extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_scc_folder_scc_big_query_export";
    /**
    * Generates CDKTF code for importing a SccFolderSccBigQueryExport resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the SccFolderSccBigQueryExport to import
    * @param importFromId The id of the existing SccFolderSccBigQueryExport that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/scc_folder_scc_big_query_export#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the SccFolderSccBigQueryExport to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google/6.12.0/docs/resources/scc_folder_scc_big_query_export google_scc_folder_scc_big_query_export} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options SccFolderSccBigQueryExportConfig
    */
    constructor(scope: Construct, id: string, config: SccFolderSccBigQueryExportConfig);
    private _bigQueryExportId?;
    get bigQueryExportId(): string;
    set bigQueryExportId(value: string);
    get bigQueryExportIdInput(): string | undefined;
    get createTime(): string;
    private _dataset?;
    get dataset(): string;
    set dataset(value: string);
    get datasetInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    get descriptionInput(): string | undefined;
    private _filter?;
    get filter(): string;
    set filter(value: string);
    get filterInput(): string | undefined;
    private _folder?;
    get folder(): string;
    set folder(value: string);
    get folderInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get mostRecentEditor(): string;
    get name(): string;
    get principal(): string;
    get updateTime(): string;
    private _timeouts;
    get timeouts(): SccFolderSccBigQueryExportTimeoutsOutputReference;
    putTimeouts(value: SccFolderSccBigQueryExportTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | SccFolderSccBigQueryExportTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
